@@ -6,15 +6,16 @@ import shutil
 import pylogconf.core
 from pytconf import register_endpoint, register_main, config_arg_parse_and_launch
 
-from pydmt.configs import ConfigSudo
+from pydmt.configs import ConfigSudo, ConfigFlow, ConfigOutput
 from pydmt.core.pydmt import PyDMT
 from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
 
-from pydmt.features.documentation import Documentation
-from pydmt.features.templating import Templating
-from pydmt.features.yaml import Yaml
-from pydmt.features.packages import Packages
-from pydmt.features.npm import Npm
+from pydmt.features.sphinx import FeatureSphinx
+from pydmt.features.mako import FeatureMako
+from pydmt.features.yaml import FeatureYaml
+from pydmt.features.apt import FeatureApt
+from pydmt.features.npm import FeatureNpm
+from pydmt.features.venv import FeatureVenv
 
 
 def add_to_path():
@@ -40,7 +41,11 @@ def add_to_path():
 
 @register_endpoint(
     description="Build the project",
-    configs=[ConfigSudo],
+    configs=[
+        ConfigSudo,
+        ConfigFlow,
+        ConfigOutput,
+    ],
 )
 def build():
     add_to_path()
@@ -48,15 +53,38 @@ def build():
     pylogconf.core.setup()
     p = PyDMT()
 
-    f = Templating()
+    f = FeatureVenv()
     f.setup(p)
-    f = Documentation()
+    f = FeatureMako()
     f.setup(p)
-    f = Yaml()
+    f = FeatureApt()
     f.setup(p)
-    f = Packages()
+    f = FeatureNpm()
     f.setup(p)
-    f = Npm()
+    f = FeatureSphinx()
+    f.setup(p)
+    f = FeatureYaml()
+    f.setup(p)
+
+    stats = p.build_all()
+    sys.exit(stats.get_os_error_code())
+
+
+@register_endpoint(
+    description="Build python virtual environment",
+    configs=[
+        ConfigSudo,
+        ConfigFlow,
+        ConfigOutput,
+    ],
+)
+def build_venv():
+    add_to_path()
+
+    pylogconf.core.setup()
+    p = PyDMT()
+
+    f = FeatureVenv()
     f.setup(p)
 
     stats = p.build_all()
@@ -65,7 +93,11 @@ def build():
 
 @register_endpoint(
     description="Build tools",
-    configs=[ConfigSudo],
+    configs=[
+        ConfigSudo,
+        ConfigFlow,
+        ConfigOutput,
+    ],
 )
 def build_tools():
     add_to_path()
@@ -73,9 +105,11 @@ def build_tools():
     pylogconf.core.setup()
     p = PyDMT()
 
-    f = Packages()
+    f = FeatureVenv()
     f.setup(p)
-    f = Npm()
+    f = FeatureApt()
+    f.setup(p)
+    f = FeatureNpm()
     f.setup(p)
 
     stats = p.build_all()
